@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.42;
+our $VERSION = 0.43;
 
 1;
 
@@ -43,6 +43,10 @@ Core library as Role (Moo) to process map data.
 
 Command Line Interface for Map::Tube::* map.
 
+=item L<Map::Tube::Cookbook>
+
+Cookbook for Map::Tube library.
+
 =item L<Map::Tube::Graph>
 
 Graph output for Map::Tube.
@@ -95,6 +99,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.42
+0.43
 
 =cut
